Coverage for /home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.stdlib/lib/python3.9/site-packages/importnb/_version.py: 77%

1# file generated by setuptools_scm

2# don't change, don't track in version control

3 TYPE_CHECKING = False 5 ctx 1abcde

4 if TYPE_CHECKING: 4 ↛ 5line 4 didn't jump to line 5, because the condition on line 4 was never true 5 ctx 1abcde

5 from typing import Tuple, Union

6 VERSION_TUPLE = Tuple[Union[int, str], ...]

7 else:

8 VERSION_TUPLE = object 5 ctx 1abcde

9

10 version: str 5 ctx 1abcde

11 __version__: str 5 ctx 1abcde

12 __version_tuple__: VERSION_TUPLE 5 ctx 1abcde

13 version_tuple: VERSION_TUPLE 5 ctx 1abcde

14

15 __version__ = version = '2023.11.1' 5 ctx 1abcde

16 __version_tuple__ = version_tuple = (2023, 11, 1) 5 ctx 1abcde